==> digikam_4.12.0.orig.tar.bz2: digikam-4.12.0/extra/kipi-plugins/yandexfotki/kipiplugin_yandexfotki.desktop.cmake <==
[Desktop Entry]
UntranslatedGenericName=Yandex.Fotki Exporter
Name=Yandex.Fotki Exporter
Name[bg]=Изнасяне към Yandex.Fotki
Name[bs]=Yandex.Fotki izvoz
Name[ca]=Exportador a Yandex.Fotki
Name[ca@valencia]=Exportador a Yandex.Fotki
Name[cs]=Exportér do Yandex.Fotki
Name[da]=Yandex.Fotki-eksportør
Name[de]=Yandex.Fotki-Export
Name[el]=Εξαγωγέας Yandex.Fotki
Name[en_GB]=Yandex.Fotki Exporter
Name[es]=Exportación a Yandex.Fotki
Name[et]=Yandex.Fotki eksportija
Name[fi]=Yandex.Fotki-vienti
Name[fr]=Outil d'exportation « Yandex.Fotki »
Name[ga]=Easpórtálaí Yandex.Fotki
Name[gl]=Exportador a Yandex.Fotki
Name[hu]=Yandex.Fotki exportáló
Name[is]=Yandex.Fotki útflutningstól
Name[it]=Esportatore a Yandex.Fotki
Name[km]=កម្មវិធី​នាំចេញ Yandex.Fotki​
Name[nb]=Yandex.Fotki eksporterer
Name[nl]=Exportprogramma van Yandex.Fotki
Name[pl]=Eksporter Yandex.Fotki
Name[pt]=Exportação para o Yandex.Fotki
Name[pt_BR]=Exportar para o Yandex.Fotki
Name[ro]=Exportator Yandex.Fotki
Name[ru]=Экспорт в Яндекс.Фотки
Name[sk]=Yandex.Fotki exportovač
Name[sl]=Izvoz v Yandex.Fotki
Name[sv]=Export till Yandex.Fotki
Name[tr]=Yandex.Fotki Aktarıcı
Name[uk]=Експорт до Яндекс.Фотки
Name[x-test]=xxYandex.Fotki Exporterxx
Name[zh_TW]=Yandex.Fotki 匯出器
Comment=A tool to export images to a remote Yandex.Fotki web service
Comment[bg]=Инструмент за изнасяне на изображения към отдалечена уеб-услуга Yandex.Fotki
Comment[bs]=Alat za izvoz slika na udaljeni Yandex.Fotki web servis
Comment[ca]=Una eina per exportar imatges al servei web remot Yandex.Fotki
Comment[ca@valencia]=Una eina per exportar imatges al servei web remot Yandex.Fotki
Comment[cs]=Nástroj pro export obrázků do vzdálené webové služby Yandex.Fotki
Comment[da]=Et værktøj til at eksportere billeder til en ekstern Yandex.Fotki webtjeneste
Comment[de]=Ein Werkzeug, um Bilder zu einem entfernten Yandex.Fotki-Webdienst zu exportieren.
Comment[el]=Εργαλείο εξαγωγής εικόνων σε μια απομακρυσμένη υπηρεσία ιστού Yandex.Fotki
Comment[en_GB]=A tool to export images to a remote Yandex.Fotki web service
Comment[es]=Una herramienta para exportar imágenes al servicio web remoto de Yandex.Fotki
Comment[et]=Tööriist piltide eksportimiseks Yandex.Fotki veebiteenusesse
Comment[fi]=Kuvien vienti Yandex.Fotki-verkkopalveluun
Comment[fr]=Outil d'exportation d'images vers le service en ligne « Yandex.Fotki »
Comment[ga]=Uirlis a easpórtálann íomhánna go seirbhís Ghréasáin Yandex.Fotki
Comment[gl]=Unha ferramenta para exportar imaxes a un servizo web Yandex.Fotki remoto
Comment[hu]=Egy eszköz képek exportálásához egy távoli Yandex.Fotk webszolgáltatásba
Comment[is]=Verkfæri til að senda myndir á fjarlæga Yandex.Fotki vefþjónustu
Comment[it]=Uno strumento per esportare immagini al servizio Web remoto Yandex.Fotki
Comment[km]=ឧបករណ៍​ត្រូវ​នាំចេញ​រូបភាព​ទៅ​សេវា​បណ្ដាញ Yandex.Fotki ពី​ចម្ងាយ
Comment[nb]=Et verktøy for å eksportere bilder til en fjern Yandex.Fotki nettjeneste
Comment[nl]=Een hulpmiddel om afbeeldingen naar een Yandex.Fotki-webservice te exporteren
Comment[pl]=Narzędzie do eksportowania obrazów do zdalnej usługi sieciowej Yandex.Fotki
Comment[pt]=Uma ferramenta para exportar imagens para o serviço Web remoto Yandex.Fotki
Comment[pt_BR]=Ferramenta para exportar imagens para o Yandex.Fotki
Comment[ro]=O unealtă de exportat imagini pe serviciul web Yandex.Fotki
Comment[ru]=Инструмент для экспорта изображений в веб-службу Яндекс.Фотки
Comment[sk]=Nástroj na export obrázkov na vzdialenú službu Yandex.Fotki
Comment[sl]=Orodje za izvoz slik v oddaljeno spletno storitev Yandex.Fotki
Comment[sv]=Ett verktyg för att exportera bilder till en Yandex.Fotki fjärrwebbtjänst
Comment[tr]=Resimleri uzak bir Yandex.Fotki web hizmetine aktarmak için bir araç
Comment[uk]=Інструмент для експорту зображень до віддаленої служби Yandex.Fotki
Comment[x-test]=xxA tool to export images to a remote Yandex.Fotki web servicexx
Comment[zh_TW]=匯出影像到遠端 Yandex.Fotki 網頁服務的工具
Type=Service
Icon=document-export
ServiceTypes=KIPI/Plugin
X-KDE-Library=kipiplugin_yandexfotki
author=Roman Tsisyk, roman at tsisyk dot com
X-KIPI-PluginCategories=Export
X-KIPI-BinaryVersion=${KIPI_SO_VERSION}

==> digikam-4.14.0.tar.bz2: digikam-4.14.0/extra/kipi-plugins/yandexfotki/kipiplugin_yandexfotki.desktop.cmake <==
[Desktop Entry]
UntranslatedGenericName=Yandex.Fotki Exporter
Name=Yandex.Fotki Exporter
Name[bg]=Изнасяне към Yandex.Fotki
Name[bs]=Yandex.Fotki izvoz
Name[ca]=Exportador a Yandex.Fotki
Name[ca@valencia]=Exportador a Yandex.Fotki
Name[cs]=Exportér do Yandex.Fotki
Name[da]=Yandex.Fotki-eksportør
Name[de]=Yandex.Fotki-Export
Name[el]=Εξαγωγέας Yandex.Fotki
Name[en_GB]=Yandex.Fotki Exporter
Name[es]=Exportación a Yandex.Fotki
Name[et]=Yandex.Fotki eksportija
Name[fi]=Yandex.Fotki-vienti
Name[fr]=Outil d'export « Yandex.Fotki »
Name[ga]=Easpórtálaí Yandex.Fotki
Name[gl]=Exportador a Yandex.Fotki
Name[hu]=Yandex.Fotki exportáló
Name[is]=Yandex.Fotki útflutningstól
Name[it]=Esportatore a Yandex.Fotki
Name[km]=កម្មវិធី​នាំចេញ Yandex.Fotki​
Name[nb]=Yandex.Fotki eksporterer
Name[nl]=Exportprogramma van Yandex.Fotki
Name[pl]=Eksporter Yandex.Fotki
Name[pt]=Exportação para o Yandex.Fotki
Name[pt_BR]=Exportar para o Yandex.Fotki
Name[ro]=Exportator Yandex.Fotki
Name[ru]=Экспорт в Яндекс.Фотки
Name[sk]=Yandex.Fotki exportovač
Name[sl]=Izvoz v Yandex.Fotki
Name[sv]=Export till Yandex.Fotki
Name[tr]=Yandex.Fotki Aktarıcı
Name[uk]=Експорт до Яндекс.Фотки
Name[x-test]=xxYandex.Fotki Exporterxx
Name[zh_TW]=Yandex.Fotki 匯出器
Comment=A tool to export images to a remote Yandex.Fotki web service
Comment[bg]=Инструмент за изнасяне на изображения към отдалечена уеб-услуга Yandex.Fotki
Comment[bs]=Alat za izvoz slika na udaljeni Yandex.Fotki web servis
Comment[ca]=Una eina per exportar imatges al servei web remot Yandex.Fotki
Comment[ca@valencia]=Una eina per exportar imatges al servei web remot Yandex.Fotki
Comment[cs]=Nástroj pro export obrázků do vzdálené webové služby Yandex.Fotki
Comment[da]=Et værktøj til at eksportere billeder til en ekstern Yandex.Fotki webtjeneste
Comment[de]=Ein Werkzeug, um Bilder zu einem entfernten Yandex.Fotki-Webdienst zu exportieren.
Comment[el]=Εργαλείο εξαγωγής εικόνων σε μια απομακρυσμένη υπηρεσία ιστού Yandex.Fotki
Comment[en_GB]=A tool to export images to a remote Yandex.Fotki web service
Comment[es]=Una herramienta para exportar imágenes al servicio web remoto de Yandex.Fotki
Comment[et]=Tööriist piltide eksportimiseks Yandex.Fotki veebiteenusesse
Comment[fi]=Kuvien vienti Yandex.Fotki-verkkopalveluun
Comment[fr]=Outil d'export d'images vers le service en ligne « Yandex.Fotki »
Comment[ga]=Uirlis a easpórtálann íomhánna go seirbhís Ghréasáin Yandex.Fotki
Comment[gl]=Unha ferramenta para exportar imaxes a un servizo web Yandex.Fotki remoto
Comment[hu]=Egy eszköz képek exportálásához egy távoli Yandex.Fotk webszolgáltatásba
Comment[is]=Verkfæri til að senda myndir á fjarlæga Yandex.Fotki vefþjónustu
Comment[it]=Uno strumento per esportare immagini al servizio Web remoto Yandex.Fotki
Comment[km]=ឧបករណ៍​ត្រូវ​នាំចេញ​រូបភាព​ទៅ​សេវា​បណ្ដាញ Yandex.Fotki ពី​ចម្ងាយ
Comment[nb]=Et verktøy for å eksportere bilder til en fjern Yandex.Fotki nettjeneste
Comment[nl]=Een hulpmiddel om afbeeldingen naar een Yandex.Fotki-webservice te exporteren
Comment[pl]=Narzędzie do eksportowania obrazów do zdalnej usługi sieciowej Yandex.Fotki
Comment[pt]=Uma ferramenta para exportar imagens para o serviço Web remoto Yandex.Fotki
Comment[pt_BR]=Ferramenta para exportar imagens para o Yandex.Fotki
Comment[ro]=O unealtă de exportat imagini pe serviciul web Yandex.Fotki
Comment[ru]=Инструмент для экспорта изображений в веб-службу Яндекс.Фотки
Comment[sk]=Nástroj na export obrázkov na vzdialenú službu Yandex.Fotki
Comment[sl]=Orodje za izvoz slik v oddaljeno spletno storitev Yandex.Fotki
Comment[sv]=Ett verktyg för att exportera bilder till en Yandex.Fotki fjärrwebbtjänst
Comment[tr]=Resimleri uzak bir Yandex.Fotki web hizmetine aktarmak için bir araç
Comment[uk]=Інструмент для експорту зображень до віддаленої служби Yandex.Fotki
Comment[x-test]=xxA tool to export images to a remote Yandex.Fotki web servicexx
Comment[zh_TW]=匯出影像到遠端 Yandex.Fotki 網頁服務的工具
Type=Service
Icon=document-export
ServiceTypes=KIPI/Plugin
X-KDE-Library=kipiplugin_yandexfotki
author=Roman Tsisyk, roman at tsisyk dot com
X-KIPI-PluginCategories=Export
X-KIPI-BinaryVersion=${KIPI_SO_VERSION}
